# 0.1.4

- Support for Pydantic version 2
- Fixes to typing
- Added Roberto as contributor

# 0.1.3

- `UrlModels` by default now includes all available Django urls on init
- Added `as_map` method for the `UrlModels` class

# 0.1.2

- Added a javascript template for URL map function

# 0.1.1

- First 'public' release as used in openly_dird
